from setuptools import setup

setup(name='cfa_distributions',
      version='1.0',
      description='Gaussian and Binomial distributions',
      packages=['cfa_distributions'],
      author='Deric Atienza',
      author_email='dericatienza@live.com.ph',
      zip_safe=False)
